@@ -52,20 +52,6 @@ class Test(unittest.TestCase):
                                                1029087.28,
                                                1490031.3600000001])
         lons, lats = area_def.get_lonlats()
-        area_def2 = geometry.AreaDefinition('areaD', 'Europe (3km, HRV, VTC)', 'areaD',
-                                            {'a': '6378144.0',
-                                             'b': '6356759.0',
-                                             'lat_0': '50.00',
-                                             'lat_ts': '50.00',
-                                             'lon_0': '8.00',
-                                             'proj': 'stere'},
-                                            800,
-                                            800,
-                                            [-1370912.72,
-                                                -909968.64000000001,
-                                                1029087.28,
-                                                1490031.3600000001],
-                                            lons=lons, lats=lats)
         lon, lat = area_def.get_lonlat(400, 400)
         self.assertAlmostEqual(lon, 5.5028467120975835,
                                msg='lon retrieval from precomputated grid failed')
@@ -91,43 +77,6 @@ class Test(unittest.TestCase):
         self.assertTrue((cart_coords.sum() - exp) < 1e-7 * exp,
                         msg='Calculation of cartesian coordinates failed')
 
-    def test_base_lat_invalid(self):
-
-        lons = np.arange(-135., +135, 20.)
-        lats = np.ones_like(lons) * 70.
-        lats[0] = -95
-        lats[1] = +95
-        self.assertRaises(
-            ValueError, geometry.BaseDefinition, lons=lons, lats=lats)
-
-    def test_base_lon_wrapping(self):
-
-        lons1 = np.arange(-135., +135, 50.)
-        lats = np.ones_like(lons1) * 70.
-
-        with catch_warnings() as w1:
-            base_def1 = geometry.BaseDefinition(lons1, lats)
-            self.assertFalse(
-                len(w1) != 0, 'Got warning <%s>, but was not expecting one' % w1)
-
-        lons2 = np.where(lons1 < 0, lons1 + 360, lons1)
-        with catch_warnings() as w2:
-            base_def2 = geometry.BaseDefinition(lons2, lats)
-            self.assertFalse(
-                len(w2) != 1, 'Failed to trigger a warning on longitude wrapping')
-            self.assertFalse(('-180:+180' not in str(w2[0].message)),
-                             'Failed to trigger correct warning about longitude wrapping')
-
-        self.assertFalse(
-            base_def1 != base_def2, 'longitude wrapping to [-180:+180] did not work')
-
-        with catch_warnings() as w3:
-            base_def3 = geometry.BaseDefinition(None, None)
-            self.assertFalse(
-                len(w3) != 0, 'Got warning <%s>, but was not expecting one' % w3)
-
-        self.assert_raises(ValueError, base_def3.get_lonlats)
-
     def test_base_type(self):
         lons1 = np.arange(-135., +135, 50.)
         lats = np.ones_like(lons1) * 70.
@@ -148,7 +97,7 @@ class Test(unittest.TestCase):
 
         # Test dtype is preserved with automatic longitude wrapping
         lons2 = np.where(lons1 < 0, lons1 + 360, lons1)
-        with catch_warnings() as w:
+        with catch_warnings():
             basedef = geometry.BaseDefinition(lons2, lats)
 
         lons, _ = basedef.get_lonlats()
@@ -157,7 +106,7 @@ class Test(unittest.TestCase):
                          (lons2.dtype, lons.dtype,))
 
         lons2_ints = lons2.astype('int')
-        with catch_warnings() as w:
+        with catch_warnings():
             basedef = geometry.BaseDefinition(lons2_ints, lats)
 
         lons, _ = basedef.get_lonlats()
@@ -216,14 +165,25 @@ class Test(unittest.TestCase):
 
     def test_get_array_hashable(self):
         arr = np.array([1.2, 1.3, 1.4, 1.5])
+        if sys.byteorder == 'little':
+            # arr.view(np.uint8)
+            reference = np.array([51,  51,  51,  51,  51,  51, 243,
+                                  63, 205, 204, 204, 204, 204,
+                                  204, 244,  63, 102, 102, 102, 102,
+                                  102, 102, 246,  63,   0,   0,
+                                  0,   0,   0,   0, 248,  63],
+                                 dtype=np.uint8)
+        else:
+            # on le machines use arr.byteswap().view(np.uint8)
+            reference = np.array([63, 243,  51,  51,  51,  51,  51,
+                                  51,  63, 244, 204, 204, 204,
+                                  204, 204, 205,  63, 246, 102, 102,
+                                  102, 102, 102, 102,  63, 248,
+                                  0,   0,   0,   0,   0,   0],
+                                 dtype=np.uint8)
 
-        np.testing.assert_allclose(np.array([ 51,  51,  51,  51,  51,  51, 243,
-                                           63, 205, 204, 204, 204, 204,
-                                           204, 244,  63, 102, 102, 102, 102,
-                                           102, 102, 246,  63,   0,   0,
-                                           0,   0,   0,   0, 248,  63],
-                                           dtype=np.uint8),
-                                    geometry.get_array_hashable(arr))
+        np.testing.assert_allclose(reference,
+                                   geometry.get_array_hashable(arr))
 
         try:
             import xarray as xr
@@ -231,19 +191,13 @@ class Test(unittest.TestCase):
             pass
         else:
             xrarr = xr.DataArray(arr)
-            np.testing.assert_allclose(np.array([ 51,  51,  51,  51,  51,  51, 243,
-                                           63, 205, 204, 204, 204, 204,
-                                           204, 244,  63, 102, 102, 102, 102,
-                                           102, 102, 246,  63,   0,   0,
-                                           0,   0,   0,   0, 248,  63],
-                                           dtype=np.uint8),
-                                    geometry.get_array_hashable(arr))
+            np.testing.assert_allclose(reference,
+                                       geometry.get_array_hashable(arr))
 
             xrarr.attrs['hash'] = 42
             self.assertEqual(geometry.get_array_hashable(xrarr),
                              xrarr.attrs['hash'])
 
-
     def test_swath_hash(self):
         lons = np.array([1.2, 1.3, 1.4, 1.5])
         lats = np.array([65.9, 65.86, 65.82, 65.78])
@@ -285,14 +239,12 @@ class Test(unittest.TestCase):
 
             self.assertIsInstance(hash(swath_def), int)
 
-
         lons = np.ma.array([1.2, 1.3, 1.4, 1.5])
         lats = np.ma.array([65.9, 65.86, 65.82, 65.78])
         swath_def = geometry.SwathDefinition(lons, lats)
 
         self.assertIsInstance(hash(swath_def), int)
 
-
     def test_area_equal(self):
         area_def = geometry.AreaDefinition('areaD', 'Europe (3km, HRV, VTC)', 'areaD',
                                            {'a': '6378144.0',
@@ -755,27 +707,6 @@ class TestSwathDefinition(unittest.TestCase):
         self.assertFalse(id(lons1) != id(lons2) or id(lats1) != id(lats2),
                          msg='Caching of swath coordinates failed')
 
-    def test_swath_wrap(self):
-        lons1 = np.fromfunction(lambda y, x: 3 + (10.0 / 100) * x, (5000, 100))
-        lats1 = np.fromfunction(
-            lambda y, x: 75 - (50.0 / 5000) * y, (5000, 100))
-
-        lons1 += 180.
-        with catch_warnings() as w1:
-            swath_def = geometry.BaseDefinition(lons1, lats1)
-            self.assertFalse(
-                len(w1) != 1, 'Failed to trigger a warning on longitude wrapping')
-            self.assertFalse(('-180:+180' not in str(w1[0].message)),
-                             'Failed to trigger correct warning about longitude wrapping')
-
-        lons2, lats2 = swath_def.get_lonlats()
-
-        self.assertTrue(id(lons1) != id(lons2),
-                        msg='Caching of swath coordinates failed with longitude wrapping')
-
-        self.assertTrue(lons2.min() > -180 and lons2.max() < 180,
-                        'Wrapping of longitudes failed for SwathDefinition')
-
     def test_concat_1d(self):
         lons1 = np.array([1, 2, 3])
         lats1 = np.array([1, 2, 3])
@@ -836,8 +767,61 @@ class TestSwathDefinition(unittest.TestCase):
         lats = np.array([65.9, 65.86, 65.82, 65.78])
         swath_def = geometry.SwathDefinition(lons, lats)
         swath_def2 = geometry.SwathDefinition(lons, lats)
+        # Identical lons and lats
         self.assertFalse(
             swath_def != swath_def2, 'swath_defs are not equal as expected')
+        # Identical objects
+        self.assertFalse(
+            swath_def != swath_def, 'swath_defs are not equal as expected')
+
+        lons = np.array([1.2, 1.3, 1.4, 1.5])
+        lats = np.array([65.9, 65.86, 65.82, 65.78])
+        lons2 = np.array([1.2, 1.3, 1.4, 1.5])
+        lats2 = np.array([65.9, 65.86, 65.82, 65.78])
+        swath_def = geometry.SwathDefinition(lons, lats)
+        swath_def2 = geometry.SwathDefinition(lons2, lats2)
+        # different arrays, same values
+        self.assertFalse(
+            swath_def != swath_def2, 'swath_defs are not equal as expected')
+
+        lons = np.array([1.2, 1.3, 1.4, np.nan])
+        lats = np.array([65.9, 65.86, 65.82, np.nan])
+        lons2 = np.array([1.2, 1.3, 1.4, np.nan])
+        lats2 = np.array([65.9, 65.86, 65.82, np.nan])
+        swath_def = geometry.SwathDefinition(lons, lats)
+        swath_def2 = geometry.SwathDefinition(lons2, lats2)
+        # different arrays, same values, with nans
+        self.assertFalse(
+            swath_def != swath_def2, 'swath_defs are not equal as expected')
+
+        try:
+            import dask.array as da
+            lons = da.from_array(np.array([1.2, 1.3, 1.4, np.nan]), chunks=2)
+            lats = da.from_array(np.array([65.9, 65.86, 65.82, np.nan]), chunks=2)
+            lons2 = da.from_array(np.array([1.2, 1.3, 1.4, np.nan]), chunks=2)
+            lats2 = da.from_array(np.array([65.9, 65.86, 65.82, np.nan]), chunks=2)
+            swath_def = geometry.SwathDefinition(lons, lats)
+            swath_def2 = geometry.SwathDefinition(lons2, lats2)
+            # different arrays, same values, with nans
+            self.assertFalse(
+                swath_def != swath_def2, 'swath_defs are not equal as expected')
+        except ImportError:
+            pass
+
+        try:
+            import xarray as xr
+            lons = xr.DataArray(np.array([1.2, 1.3, 1.4, np.nan]))
+            lats = xr.DataArray(np.array([65.9, 65.86, 65.82, np.nan]))
+            lons2 = xr.DataArray(np.array([1.2, 1.3, 1.4, np.nan]))
+            lats2 = xr.DataArray(np.array([65.9, 65.86, 65.82, np.nan]))
+            swath_def = geometry.SwathDefinition(lons, lats)
+            swath_def2 = geometry.SwathDefinition(lons2, lats2)
+            # different arrays, same values, with nans
+            self.assertFalse(
+                swath_def != swath_def2, 'swath_defs are not equal as expected')
+
+        except ImportError:
+            pass
 
     def test_swath_not_equal(self):
         """Test swath inequality."""
@@ -894,7 +878,7 @@ class TestSwathDefinition(unittest.TestCase):
 
         lons = np.array([[-45., 0., 45.],
                          [-90, 0., 90.],
-                         [-135., 180., 135.]]).T
+                         [-135., -180., 135.]]).T
 
         area = geometry.SwathDefinition(lons, lats)
         lons, lats = area.get_edge_lonlats()
@@ -1079,7 +1063,7 @@ class TestStackedAreaDefinition(unittest.TestCase):
         area2.y_size = random.randrange(6425)
         area2.x_size = x_size
 
-        res = concatenate_area_defs(area1, area2)
+        concatenate_area_defs(area1, area2)
         area_extent = [1, 2, 3, 6]
         y_size = area1.y_size + area2.y_size
         adef.assert_called_once_with(area1.area_id, area1.name, area1.proj_id,
